@@ -10,6 +10,7 @@
 from climetlab.helpers import helper
 from climetlab.core.ipython import display
 from .drivers.magics import Driver
+from climetlab.core import docstring
 
 
 class Plot:
@@ -20,6 +21,13 @@ class Plot:
         self.driver = Driver(kwargs)
 
     def plot_map(self, data, **kwargs):
+
+        # try:
+        #     iter(data)
+        #     data = list(data)
+        # except Exception:
+        #     pass
+
         if not isinstance(data, (list, tuple)):
             data = [data]
 
@@ -27,7 +35,8 @@ class Plot:
             if getattr(d, "plot_map", None) is None:
                 d = helper(d)
 
-        d.plot_map(self.driver)
+            d.plot_map(self.driver)
+
         self.driver.apply_options(kwargs)
 
     def show(self):
@@ -46,16 +55,17 @@ def new_plot(**kwargs) -> Plot:
     return Plot(kwargs)
 
 
+@docstring()
 def plot_map(data, **kwargs):
-    """Foo bar
+    """Plot any data on a map.
 
-    Args:
-        data (str): Kdd
-
-    Returns:
-        str: path
+        Args:
+            data ([any]): [description]
     """
 
     p = new_plot(**kwargs)
     p.plot_map(data)
     p.show()
+
+
+Plot.plot_map.__doc__ = plot_map.__doc__
